<?php

namespace app\api\logic\Code;

use app\common\model\Code\CodeModuleCategory as ModelCodeModuleCategory;
use app\common\model\Code\CodeModule as ModelCodeModule;
use app\common\model\Token as ModelToken;
use app\common\exception\Tool;


class CodeModule
{
    /**
     * 代码块新增验证
     * 
     * @param array $params 新增代码的参数
     * @return void
     * @date 2023-07-12
     * @author xjh
     * @since 1.0.0
     */
    public static function validateAddCodeModule(array $params): void
    {
        if ($params['code_module_category_guid'] != ModelCodeModuleCategory::MASTER_DEFAULT) {
            $category = ModelCodeModuleCategory::find($params['code_module_category_guid']);
            if ($category) {
                if ($category->customer_guid != ModelToken::getCurrentCustomer()->customer_guid) {
                    throwErrorMsg("所选的上级类目不属于当前客户!");
                }
            } else {
                throwErrorMsg("所选的上级类目不存在!");
            }
        }
    }

    /**
     * 代码块编辑验证
     * 
     * @param string $code_module_guid 代码块guid
     * @return array
     * @date 2023-07-14
     * @author xjh
     * @since 1.0.0
     */
    public static function validateEditCodeModule(string $code_module_guid): void
    {
        $module = ModelCodeModule::find($code_module_guid);
        if (!$module) {
            throwErrorMsg("所编辑的代码块不存在!");
        }
        if ($module->customer_guid != ModelToken::getCurrentCustomer()->customer_guid) {
            throwErrorMsg("所编辑的代码块不属于当前客户!");
        }
    }
}